@@ -21,6 +21,7 @@
 #include "contactsservice.h"
 #include "contact.h"
 #include "contactsgroup.h"
+#include "utils.h"
 #include "../debug.h"
 
 #include <QDomDocument>
@@ -420,7 +421,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
             if (event.value(QStringLiteral("rel")).toString() == QLatin1String("anniversary")) {
                 QVariantMap when = event.value(QStringLiteral("gd$when")).toMap();
-                contact->setAnniversary(when.value(QStringLiteral("startTime")).toString());
+                contact->setAnniversary(QDate::fromString(when.value(QStringLiteral("startTime")).toString(), Qt::ISODate));
             }
         }
     }
@@ -448,7 +449,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
                 locator.setParameters({ { QStringLiteral("TYPE"), { QStringLiteral("PROFILE") } } });
                 contact->insertExtraUrl(locator);
             } else if (rel == QLatin1String("blog")) {
-                contact->setBlogFeed(url.toString(QUrl::PrettyDecoded));
+                contact->setBlogFeed(url);
             } else {
                 KContacts::ResourceLocatorUrl locator;
                 locator.setUrl(url);
@@ -674,14 +675,14 @@ QByteArray contactToXML(const ContactPtr& contact)
     }
 
     /* Anniversary */
-    const QString anniversary = contact->anniversary();
+    const QString anniversary = contact->anniversary().toString(Qt::ISODate);
     if (!anniversary.isEmpty()) {
         output.append("<gContact:event rel=\"anniversary\"><gd:when startTime=\"").append(anniversary.toHtmlEscaped().toUtf8()).append("\" /></gContact:event>");
         parsedCustoms << QStringLiteral("KADDRESSBOOK-X-Anniversary");
     }
 
     /* Blog */
-    const QString blog = contact->blogFeed();
+    const QString blog = contact->blogFeed().url();
     if (!blog.isEmpty()) {
         output.append("<gContact:website rel=\"blog\" href=\"").append(blog.toHtmlEscaped().toUtf8()).append("\" />");
         parsedCustoms << QStringLiteral("KADDRESSBOOK-BlogFeed");
@@ -712,6 +713,9 @@ QByteArray contactToXML(const ContactPtr& contact)
 
     /* IMs */
     const QString im_str = QStringLiteral("<gd:im address=\"%1\" protocol=\"%2\" rel=\"http://schemas.google.com/g/2005#other\" primary=\"%3\"/>");
+    Q_FOREACH(const auto &impp, contact->imppList()) {
+        output.append(im_str.arg(impp.address().path(), Contact::IMProtocolNameToScheme(impp.serviceType()), Utils::bool2Str(impp.isPreferred())).toUtf8());
+    }
     Q_FOREACH(const QString &im, contact->customs()) {
         if (im.startsWith(QLatin1String("messaging/"))) {
             QString key = im.left(im.indexOf(QLatin1Char(':')));
@@ -719,8 +723,7 @@ QByteArray contactToXML(const ContactPtr& contact)
             QString proto = key.mid(10);
             proto.chop(4);
             bool primary = (contact->custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-IMAddress")) == value);
-            output.append(im_str.arg(value, Contact::IMProtocolNameToScheme(proto),
-                                     (primary ? QStringLiteral("true") : QStringLiteral("false"))).toUtf8());
+            output.append(im_str.arg(value, Contact::IMProtocolNameToScheme(proto), Utils::bool2Str(primary)).toUtf8());
             parsedCustoms << key;
         /* X-messaging is probably a new key (?) used by KAddressbook when importing
          * contacts from vCard. */
@@ -1009,7 +1012,7 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
         if (e.tagName() == QLatin1String("gContact:event")) {
             if (e.attribute(QStringLiteral("rel"), QString()) == QLatin1String("anniversary")) {
                 QDomElement w = e.firstChildElement(QStringLiteral("gd:when"));
-                contact->setAnniversary(w.attribute(QStringLiteral("startTime"), QString()));
+                contact->setAnniversary(QDate::fromString(w.attribute(QStringLiteral("startTime"), QString()), Qt::ISODate));
             }
 
             continue;
@@ -1018,7 +1021,7 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
         /* Websites */
         if (e.tagName() == QLatin1String("gContact:website")) {
             if (e.attribute(QStringLiteral("rel"), QString()) == QLatin1String("blog")) {
-                contact->setBlogFeed(e.attribute(QStringLiteral("href"), QString()));
+                contact->setBlogFeed(QUrl(e.attribute(QStringLiteral("href"), QString())));
                 continue;
             }
 
