@@ -15,7 +15,7 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI2_DRIVE_APP_H
@@ -25,10 +25,10 @@
 #include "object.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QSharedPointer>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QUrl>
+#include <QSharedPointer>
+#include <QString>
+#include <QStringList>
+#include <QUrl>
 
 namespace KGAPI2
 {
@@ -55,6 +55,8 @@ class KGAPIDRIVE_EXPORT App: public KGAPI2::Object
         explicit Icon();
         explicit Icon(const Icon &other);
         virtual ~Icon();
+        bool operator==(const Icon &other) const;
+        bool operator!=(const Icon &other) const { return !operator==(other); }
 
         Category category() const;
         int size() const;
@@ -73,6 +75,8 @@ class KGAPIDRIVE_EXPORT App: public KGAPI2::Object
     explicit App();
     explicit App(const App &other);
     virtual ~App();
+    bool operator==(const App &other) const;
+    bool operator!=(const App &other) const { return !operator==(other); }
 
     QString id() const;
     QString name() const;
